import unittest
import datetime

from rss_reader.rss_reader import FeedGenerator, output_data


class RssReaderTest(unittest.TestCase):

    def test_feed_geneartion(self):

        fd = FeedGenerator("https://news.yahoo.com/rss/")
        data = fd.collect_data()

        self.assertTrue(len(data) > 0)

    def test_limit(self):

        fd = FeedGenerator("https://news.yahoo.com/rss/", limit=1)

        self.assertEqual(len(fd.collect_data()['Entries']), 1)


    def test_output_data(self):
        entries = [
            {'title': 'Test title',
             'published': datetime.datetime.now(),
             'link': 'Test link'},
             ]
        test_data = output_data({'Feed': 'Test feed', 'Entries': entries})

        self.assertEqual(type(test_data), str)



import os
from setuptools import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "rss-reader-bektur",
    version = "2.1.1",
    author = "Bektur Soltobaev",
    author_email = "bektur_soltobaev@epam.com",
    description = ("RSS reader for final task in Python educational course"),
    license = "BSD",
    keywords = "rss reader exam",
    url = "http://packages.python.org/rss-reader",
    packages=['rss_reader', 'tests'],
    long_description=read('README.md'),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: BSD License",
    ],
    entry_points = {
        'console_scripts': ['rss-reader=rss_reader.rss_reader:cli'],
    },
)
